summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/addglobaldlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/addglobaldlg.cpp')
-rw-r--r--parts/filecreate/addglobaldlg.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/parts/filecreate/addglobaldlg.cpp b/parts/filecreate/addglobaldlg.cpp
index 11a0f2a6..ca31669f 100644
--- a/parts/filecreate/addglobaldlg.cpp
+++ b/parts/filecreate/addglobaldlg.cpp
@@ -21,14 +21,14 @@
#include <klocale.h>
/*
* Constructs a AddGlobalDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddGlobalDlg::AddGlobalDlg( TQWidget* parent, const char* name, bool modal, WFlags fl )
- : TQDialog( parent, name, modal, fl )
+AddGlobalDlg::AddGlobalDlg( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : TQDialog( tqparent, name, modal, fl )
{
if ( !name )
@@ -68,7 +68,7 @@ AddGlobalDlg::AddGlobalDlg( TQWidget* parent, const char* name, bool modal, WFla
AddGlobalDlgLayout->addWidget( fcglobal_view, 0, 0 );
languageChange();
- resize( TQSize(511, 282).expandedTo(minimumSizeHint()) );
+ resize( TQSize(511, 282).expandedTo(tqminimumSizeHint()) );
// signals and slots connections
connect( buttonOk, TQT_SIGNAL( clicked() ), this, TQT_SLOT( accept() ) );
@@ -80,7 +80,7 @@ AddGlobalDlg::AddGlobalDlg( TQWidget* parent, const char* name, bool modal, WFla
*/
AddGlobalDlg::~AddGlobalDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -93,9 +93,9 @@ void AddGlobalDlg::languageChange()
buttonHelp->setGuiItem( KStdGuiItem::help() );
buttonHelp->setAccel( TQKeySequence( tr2i18n( "F1" ) ) );
buttonOk->setGuiItem( KStdGuiItem::ok() );
- buttonOk->setAccel( TQKeySequence( TQString::null ) );
+ buttonOk->setAccel( TQKeySequence( TQString() ) );
buttonCancel->setGuiItem( KStdGuiItem::cancel() );
- buttonCancel->setAccel( TQKeySequence( TQString::null ) );
+ buttonCancel->setAccel( TQKeySequence( TQString() ) );
fcglobal_view->header()->setLabel( 0, i18n( "Type extension:" ) );
fcglobal_view->header()->setLabel( 1, i18n( "Type name:" ) );
fcglobal_view->header()->setLabel( 2, i18n( "Template location:" ) );
@@ -21,14 +21,14 @@
#include <klocale.h>
/*
- * Constructs a AddGlobalDlg as a child of 'parent', with the
+ * Constructs a AddGlobalDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*